@@ -17,7 +17,6 @@ BEGIN {
     'WORKSHEET' => 'Excel::Template::Container::Worksheet',
 
     'CELL'      => 'Excel::Template::Element::Cell',
-    'COLUMN'    => 'Excel::Template::Element::Column',
     'FORMULA'   => 'Excel::Template::Element::Formula',
     'VAR'       => 'Excel::Template::Element::Var',
 
@@ -47,7 +46,6 @@ BEGIN {
 %isBuildable = map { $_ => 1 } qw(
     BOLD
     CELL
-    COLUMN
     FORMAT
     FORMULA
     IF
